Struct libpatron::ir::SignalInfo
source · pub struct SignalInfo {
pub name: Option<StringRef>,
pub kind: SignalKind,
}Fields
name: Option<StringRef>kind: SignalKindTrait Implementations
sourceimpl Clone for SignalInfo
impl Clone for SignalInfo
sourcefn clone(&self) -> SignalInfo
fn clone(&self) -> SignalInfo
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for SignalInfo
impl Debug for SignalInfo
sourceimpl GetNode<SignalInfo, ExprRef> for TransitionSystem
impl GetNode<SignalInfo, ExprRef> for TransitionSystem
sourcefn get(&self, reference: ExprRef) -> &SignalInfo
fn get(&self, reference: ExprRef) -> &SignalInfo
Lookup the value by the reference obtained from a call to add
sourceimpl Hash for SignalInfo
impl Hash for SignalInfo
sourceimpl PartialEq for SignalInfo
impl PartialEq for SignalInfo
sourcefn eq(&self, other: &SignalInfo) -> bool
fn eq(&self, other: &SignalInfo) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Eq for SignalInfo
impl StructuralEq for SignalInfo
impl StructuralPartialEq for SignalInfo