pub struct SmtModelCheckerOptions {
pub check_constraints: bool,
pub check_bad_states_individually: bool,
pub save_smt_replay: bool,
}Fields
check_constraints: boolPerform additional checking to ensure that the assumptions are satisfiable.
check_bad_states_individually: boolPerform one SMT solver check per assertion instead of combining them into a single check.
save_smt_replay: boolIf true, the communication with the SMT solver will be logged into a replay.smt file.